User prompt
Please fix the bug: 'TypeError: LK.playSound is not a function' in or related to this line: 'LK.playSound('pop');' Line Number: 46
User prompt
Please fix the bug: 'TypeError: LK.playSound is not a function' in or related to this line: 'LK.playSound('pop');' Line Number: 86
Code edit (2 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: LK.clearAll is not a function' in or related to this line: 'LK.clearAll();' Line Number: 196
User prompt
Please fix the bug: 'TypeError: LK.playSound is not a function' in or related to this line: 'LK.playSound('pop');' Line Number: 45
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: LK.clearAll is not a function' in or related to this line: 'LK.clearAll(); // Clear all objects from the game' Line Number: 214
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: game.end is not a function' in or related to this line: 'game.end();' Line Number: 84
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'TypeError: game.clear is not a function' in or related to this line: 'game.clear(); // Clear all objects from the game' Line Number: 212
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Timeout.tick error: game.clear is not a function' in or related to this line: 'game.clear(); // Clear all objects from the game' Line Number: 206
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Timeout.tick error: game.clear is not a function' in or related to this line: 'game.clear(); // Clear all objects from the game' Line Number: 198
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Timeout.tick error: game.clear is not a function' in or related to this line: 'game.clear(); // Clear all objects from the game' Line Number: 194
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Timeout.tick error: game.clear is not a function' in or related to this line: 'game.clear(); // Clear all objects from the game' Line Number: 156
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Timeout.tick error: game.clear is not a function' in or related to this line: 'game.clear(); // Clear all objects from the game' Line Number: 152
Code edit (1 edits merged)
Please save this source code
User prompt
Please fix the bug: 'Timeout.tick error: LK.clearAll is not a function' in or related to this line: 'LK.clearAll(); // Clear all objects from the game' Line Number: 141
===================================================================
--- original.js
+++ change.js
@@ -21,10 +21,12 @@
// Update function to move the balloon
self.update = function () {
self.y -= self.speed;
self.x += self.direction;
// If the balloon goes off screen, reset its position
if (self.y < -100) {
+ LK.setScore(LK.getScore() - 1); // Decrease score for missed balloon
+ scoreTxt.setText(LK.getScore());
self.y = 2732 + 100;
self.x = Math.random() * 2048;
}
};
@@ -54,10 +56,12 @@
// Update function to move the balloon
self.update = function () {
self.y -= self.speed;
self.x += self.direction;
// If the balloon goes off screen, reset its position
if (self.y < -100) {
+ LK.setScore(LK.getScore() - 2); // Decrease more score for missed Balloon2
+ scoreTxt.setText(LK.getScore());
self.y = 2732 + 100;
self.x = Math.random() * 2048;
}
};
@@ -183,8 +187,9 @@
/****
* Game Over Screen
****/
game.end = function () {
+ game.clear(); // Clear all objects from the game
var gameOverTxt = new Text2('Game Over! Score: ' + LK.getScore(), {
size: 150,
fill: 0xFFFFFF
@@ -21,10 +21,12 @@
self.y -= self.speed;
self.x += self.direction;
- // If the balloon goes off screen, reset its position
+ // If the balloon goes off screen, reset its position and decrease score
if (self.y < -100) {
@@ -54,10 +56,12 @@
self.y -= self.speed;
self.x += self.direction;
- // If the balloon goes off screen, reset its position
+ // If the balloon goes off screen, reset its position and decrease score
if (self.y < -100) {
});